@@ -1,12 +1,19 @@
 
-# function to return tibble with NAs as specified
-# list_NA(c("mean", "lwr.ci", "upr.ci"))
-list_NA <- function(...) {
-  names <- c(...)
-  results <- as.list(c(rep(NA, length(names))))
-  names(results) <- names
-  results <- tibble::as_tibble(results)
-  results[1:length(results)] <- as.numeric(results[1:length(results)])
+#' List NA
+#'
+#' function to return tibble with NAs as specified
+#' @param x named vector 
+#'
+#' @importFrom tibble enframe
+#' @importFrom tidyr pivot_wider
+#' @return empty tibble
+#' @keywords internal
+list_NA <- function(x) {
+  names <- x
+  
+  results <- tibble::enframe(names) %>%
+    mutate(value = as.numeric(.data$value)) %>%
+    tidyr::pivot_wider()
   return(results)
 }
 
@@ -14,7 +21,7 @@ list_NA <- function(...) {
 #' Open Window
 #' 
 #' calculates the period at each row from the row of interest
-#' @param x dateframe
+#' @param x dataframe
 #' @param tcolumn time column
 #' @param unit unit
 #' @param n desired n
